==> mailtmpy-0.1.0-py3-none-any.whl: mailtmpy/email.py <==
from .helpers import username_gen, password_gen
from .listen import Listen
from .models import Credentials, Message


class Email(Listen):
    domain = ""
    address = ""
    password = ""

    def __init__(self):
        super().__init__()

        if self.get_domain() is not False:
            print("Failed to get domains")

    def get_domain(self):
        url = "https://api.mail.tm/domains"
        response = self.session.get(url)
        response.raise_for_status()

        try:
            data = response.json()
            for domain in data['hydra:member']:
                if domain['isActive']:
                    self.domain = domain['domain']
                    return self.domain

            raise Exception("No Domain")
        except:
            return False

    def register(self, username=None, password=None, domain=None):
        self.domain = domain if domain else self.domain
        username = username if username else username_gen()
        password = password if password else password_gen()

        url = "https://api.mail.tm/accounts"
        payload = {
            "address": f"{username}@{self.domain}",
            "password": password
        }
        headers = {'Content-Type': 'application/json'}
        response = self.session.post(url, headers=headers, json=payload)
        response.raise_for_status()

        data = response.json()
        try:
            self.address = data['address']
        except:
            self.address = f"{username}@{self.domain}"
        self.password = password

        self.get_token()

        if not self.address:
            raise Exception("Failed to make an address")

        return Credentials(username=self.address, password=self.password)

    def login(self, address: str, password: str) -> None:
        self.address = address
        self.password = password
        self.get_token()
        return Credentials(username=self.address, password=self.password)

    def get_token(self):
        url = "https://api.mail.tm/token"
        payload = {
            "address": self.address,
            "password": self.password
        }
        headers = {'Content-Type': 'application/json'}
        response = self.session.post(url, headers=headers, json=payload)
        response.raise_for_status()
        try:
            self.token = response.json()['token']
        except:
            raise Exception("Failed to get token")

        return self.token


if __name__ == "__main__":
    def handler(message: Message):
        print("\nNew Message:")
        print('From:', message.from_)
        print("Subject:", message.subject)
        print("Content:", message.text
              if message.text else message.html)

    # Get Domains
    test = Email()
    print("\nDomain: " + test.domain)

    # Make new email address
    test.register()
    print("\nEmail Adress:", test.address)
    print("Email Password:", test.password)

    # Start listening
    test.start(handler)
    print("\nWaiting for new emails...")

    # Wait for new message
    # test.start()
    # print("\nScript execution is paused. Waiting for new email...")
    # message = test.wait_for_new_message()
    # print("New message is recieved, script execution is resumed.")
    # handler(message)

    # Stop listening
    # test.stop()

==> mailtmpy-0.1.1-py3-none-any.whl: mailtmpy/email.py <==
from .helpers import username_gen, password_gen
from .listen import Listen
from .models import Credentials, Message


class Email(Listen):
    domain = ""
    address = ""
    password = ""

    def __init__(self):
        super().__init__()

        if self.get_domain() is not False:
            print("Failed to get domains")

    def get_domain(self) -> str | False:
        url = "https://api.mail.tm/domains"
        response = self.session.get(url)
        response.raise_for_status()

        try:
            data = response.json()
            for domain in data['hydra:member']:
                if domain['isActive']:
                    self.domain = domain['domain']
                    return self.domain

            raise Exception("No Domain")
        except:
            return False

    def register(self, username=None, password=None, domain=None) -> Credentials:
        self.domain = domain if domain else self.domain
        username = username if username else username_gen()
        password = password if password else password_gen()

        url = "https://api.mail.tm/accounts"
        payload = {
            "address": f"{username}@{self.domain}",
            "password": password
        }
        headers = {'Content-Type': 'application/json'}
        response = self.session.post(url, headers=headers, json=payload)
        response.raise_for_status()

        data = response.json()
        try:
            self.address = data['address']
        except:
            self.address = f"{username}@{self.domain}"
        self.password = password

        self.get_token()

        if not self.address:
            raise Exception("Failed to make an address")

        return Credentials(address=self.address, password=self.password)

    def login(self, address: str, password: str) -> Credentials:
        self.address = address
        self.password = password
        self.get_token()
        return Credentials(address=self.address, password=self.password)

    def get_token(self) -> str:
        url = "https://api.mail.tm/token"
        payload = {
            "address": self.address,
            "password": self.password
        }
        headers = {'Content-Type': 'application/json'}
        response = self.session.post(url, headers=headers, json=payload)
        response.raise_for_status()
        try:
            self.token = response.json()['token']
        except:
            raise Exception("Failed to get token")

        return self.token


if __name__ == "__main__":
    def handler(message: Message):
        print("\nNew Message:")
        print('From:', message.from_)
        print("Subject:", message.subject)
        print("Content:", message.text
              if message.text else message.html)

    # Get Domains
    test = Email()
    print("\nDomain: " + test.domain)

    # Make new email address
    test.register()
    print("\nEmail Adress:", test.address)
    print("Email Password:", test.password)

    # Start listening
    test.start(handler)
    print("\nWaiting for new emails...")

    # Wait for new message
    # test.start()
    # print("\nScript execution is paused. Waiting for new email...")
    # message = test.wait_for_new_message()
    # print("New message is recieved, script execution is resumed.")
    # handler(message)

    # Stop listening
    # test.stop()
